@@ -1,4 +1,6 @@
-from dataclasses import dataclass
+from dataclasses import dataclass, field
+from typing import List
+
 
 @dataclass
 class Property:
@@ -7,6 +9,4 @@ class Property:
     Access_modifiers: str = ''
     Is_static: bool = False
     Return_type: str = ''
-    Has_get: bool = False
-    Has_set: bool = False
-    Return_value: str = 'false'
+    Return_values: List[str] = field(default_factory=list)
